@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::Simple;
 # ABSTRACT: simple parsing of RFC2822 message format and headers
-$Email::Simple::VERSION = '2.215'; # TRIAL
+$Email::Simple::VERSION = '2.217'; # TRIAL
 use Carp ();
 
 use Email::Simple::Creator;
@@ -78,6 +78,8 @@ sub new {
 
   my $text_ref = (ref $text || '' eq 'SCALAR') ? $text : \$text;
 
+  Carp::carp 'Message with wide characters' if ${$text_ref} =~ /[^\x00-\xFF]/;
+
   my ($pos, $mycrlf) = $class->_split_head_from_body($text_ref);
 
   my $self = bless { mycrlf => $mycrlf } => $class;
@@ -303,6 +305,7 @@ sub body {
 sub body_set {
   my ($self, $text) = @_;
   my $text_ref = ref $text ? $text : \$text;
+  Carp::carp 'Body with wide characters' if defined ${$text_ref} and ${$text_ref} =~ /[^\x00-\xFF]/;
   $self->{body} = $text_ref;
   return;
 }
@@ -348,7 +351,7 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
 =head1 VERSION
 
-version 2.215
+version 2.217
 
 =head1 SYNOPSIS
 
