@@ -2,7 +2,9 @@ use strict;
 use warnings;
 package Email::Simple::Creator;
 # ABSTRACT: private helper for building Email::Simple objects
-$Email::Simple::Creator::VERSION = '2.215'; # TRIAL
+$Email::Simple::Creator::VERSION = '2.217'; # TRIAL
+use Carp ();
+
 sub _crlf {
   "\x0d\x0a";
 }
@@ -18,6 +20,9 @@ sub _add_to_header {
   my ($class, $header, $key, $value) = @_;
   $value = '' unless defined $value;
 
+  Carp::carp "Header name '$key' with wide characters" if $key =~ /[^\x00-\xFF]/;
+  Carp::carp "Value '$value' for '$key' header with wide characters" if $value =~ /[^\x00-\xFF]/;
+
   if ($value =~ s/[\x0a\x0b\x0c\x0d\x85\x{2028}\x{2029}]+/ /g) {
     Carp::carp("replaced vertical whitespace in $key header with space; this will become fatal in a future version");
   }
@@ -44,7 +49,7 @@ Email::Simple::Creator - private helper for building Email::Simple objects
 
 =head1 VERSION
 
-version 2.215
+version 2.217
 
 =head1 AUTHORS
 
