@@ -2,9 +2,11 @@ use strict;
 use warnings;
 package Email::Simple::Header;
 # ABSTRACT: the header of an Email::Simple message
-$Email::Simple::Header::VERSION = '2.215'; # TRIAL
+$Email::Simple::Header::VERSION = '2.217'; # TRIAL
 use Carp ();
 
+our @CARP_NOT = qw(Email::Simple);
+
 require Email::Simple;
 
 #pod =head1 SYNOPSIS
@@ -59,6 +61,8 @@ sub new {
 sub _header_to_list {
   my ($self, $head, $mycrlf) = @_;
 
+  Carp::carp 'Header with wide characters' if ${$head} =~ /[^\x00-\xFF]/;
+
   my @headers;
 
   my $crlf = Email::Simple->__crlf_re;
@@ -245,6 +249,9 @@ sub header_raw {
 sub header_raw_set {
   my ($self, $field, @data) = @_;
 
+  Carp::carp "Header name '$field' with wide characters" if $field =~ /[^\x00-\xFF]/;
+  Carp::carp "Value for '$field' header with wide characters" if grep /[^\x00-\xFF]/, @data;
+
   # I hate this block. -- rjbs, 2006-10-06
   if ($Email::Simple::GROUCHY) {
     Carp::croak "field name contains illegal characters"
@@ -306,6 +313,63 @@ sub header_raw_prepend {
   return;
 }
 
+#pod =method header_rename
+#pod
+#pod   $header->header_rename($field, $new_name, $nth);
+#pod
+#pod This renames the named field to the new name.  If C<$nth> is given, only the
+#pod I<n>th instance of the field will be renamed.  It is fatal to rename an
+#pod instance that does not exist.  The first instance of a header is the 0th.
+#pod
+#pod If C<$nth> is omitted, all instances of the header are renamed.
+#pod
+#pod When picking headers to rename, C<$field> is matched case insensitively.  So,
+#pod given this header:
+#pod
+#pod     happythoughts: yes
+#pod     HappyThoughts: so many
+#pod     hapPyThouGhts: forever
+#pod
+#pod Then this code...
+#pod
+#pod     $header->rename_header('happythoughts', 'Delights');
+#pod
+#pod ...will result in this:
+#pod
+#pod     Delights: yes
+#pod     Delights: so many
+#pod     Delights: forever
+#pod
+#pod Headers may be rewrapped as a result of renaming.
+#pod
+#pod =cut
+
+sub header_rename {
+  my ($self, $field, $new_name, $n) = @_;
+
+  my $headers = $self->{headers};
+  my $lc_field = lc $field;
+
+  my @indices = grep { lc $headers->[$_] eq $lc_field }
+    map { $_ * 2 } 0 .. @$headers / 2 - 1;
+
+  if (defined $n) {
+    if ($n < 0) { Carp::confess("negative header index makes no sense") }
+    if ($n > $#indices) { Carp::confess("$n exceeds count of $field headers") }
+
+    @indices = $indices[$n];
+  }
+
+  for my $i (@indices) {
+    $headers->[$i] = $new_name;
+    if (ref $headers->[$i + 1]) {
+      $headers->[$i + 1] = $headers->[ $i + 1 ][0];
+    }
+  }
+
+  return;
+}
+
 #pod =method crlf
 #pod
 #pod This method returns the newline string used in the header.
@@ -412,7 +476,7 @@ Email::Simple::Header - the header of an Email::Simple message
 
 =head1 VERSION
 
-version 2.215
+version 2.217
 
 =head1 SYNOPSIS
 
@@ -506,6 +570,35 @@ you.)
 This method adds a new instance of the name field as the first field in the
 header.
 
+=head2 header_rename
+
+  $header->header_rename($field, $new_name, $nth);
+
+This renames the named field to the new name.  If C<$nth> is given, only the
+I<n>th instance of the field will be renamed.  It is fatal to rename an
+instance that does not exist.  The first instance of a header is the 0th.
+
+If C<$nth> is omitted, all instances of the header are renamed.
+
+When picking headers to rename, C<$field> is matched case insensitively.  So,
+given this header:
+
+    happythoughts: yes
+    HappyThoughts: so many
+    hapPyThouGhts: forever
+
+Then this code...
+
+    $header->rename_header('happythoughts', 'Delights');
+
+...will result in this:
+
+    Delights: yes
+    Delights: so many
+    Delights: forever
+
+Headers may be rewrapped as a result of renaming.
+
 =head2 crlf
 
 This method returns the newline string used in the header.
